@@ -11,4 +11,9 @@ def screen_unmarked_image(dir_path):
 
 @except_dec()
 def change_label_in_xml(dir_path, old_label, new_label):
-    ruiming.change_label_in_xml(dir_path, old_label, new_label)
\ No newline at end of file
+    ruiming.change_label_in_xml(dir_path, old_label, new_label)
+
+
+@except_dec()
+def screen_without_label_json_file(dir_path):
+    ruiming.screen_without_label_json_file(dir_path)
\ No newline at end of file
